#include "xslt.h"
const char *xslt_library = 
"<?xml version=\"1.0\"?>\n"
"<xsl:stylesheet	xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\" \n"
"				xmlns:swft=\"http://subsignal.org/swfml/swft\"\n"
"				xmlns:str=\"http://exslt.org/strings\"\n"
"				xmlns:math=\"http://exslt.org/math\"\n"
"				xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\"\n"
"				xmlns:svg=\"http://www.w3.org/2000/svg\"\n"
"				extension-element-prefixes=\"swft\"\n"
"				version='1.0'>\n"
"\n"
"<xsl:output method=\"xml\" indent=\"yes\"/>\n"
"\n"
"<!-- basic SWF setup -->\n"
"<xsl:template match=\"movie\">\n"
"	<!-- set defaults for movie -->\n"
"	<xsl:variable name=\"version\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@version\"><xsl:value-of select=\"@version\"/></xsl:when>\n"
"			<xsl:otherwise>7</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"compressed\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@compressed='true'\">1</xsl:when>\n"
"			<xsl:when test=\"@compressed='false'\">0</xsl:when>\n"
"			<xsl:otherwise>1</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"framerate\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@framerate\"><xsl:value-of select=\"@framerate\"/></xsl:when>\n"
"			<xsl:otherwise>12</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"frames\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@frames\"><xsl:value-of select=\"@frames\"/></xsl:when>\n"
"			<xsl:otherwise>1</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"left\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@left\"><xsl:value-of select=\"@left * 20\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"top\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@top\"><xsl:value-of select=\"@top * 20\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"right\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@width\"><xsl:value-of select=\"$left + (@width * 20)\"/></xsl:when>\n"
"			<xsl:otherwise>6400</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"bottom\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@height\"><xsl:value-of select=\"$top + (@height * 20)\"/></xsl:when>\n"
"			<xsl:otherwise>4800</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"\n"
"	<swf version=\"{$version}\" compressed=\"{$compressed}\">\n"
"		<Header framerate=\"{$framerate}\" frames=\"{$frames}\">\n"
"			<size>\n"
"				<Rectangle left=\"{$left}\" right=\"{$right}\" top=\"{$top}\" bottom=\"{$bottom}\"/>\n"
"			</size>\n"
"			<tags>\n"
"				<xsl:apply-templates/>\n"
"				<End/>\n"
"			</tags>\n"
"		</Header>\n"
"	</swf>\n"
"</xsl:template>\n"
"\n"
"<!-- Color from @color=\"#rrggbb\" or @red, @green, @blue-->\n"
"<xsl:template name=\"color\">\n"
"	<xsl:variable name=\"red\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@red\"><xsl:value-of select=\"@red\"/></xsl:when>\n"
"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,2,2)\"/></xsl:when>\n"
"			<xsl:otherwise>200</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"green\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@green\"><xsl:value-of select=\"@green\"/></xsl:when>\n"
"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,4,2)\"/></xsl:when>\n"
"			<xsl:otherwise>200</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"blue\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@blue\"><xsl:value-of select=\"@blue\"/></xsl:when>\n"
"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,6)\"/></xsl:when>\n"
"			<xsl:otherwise>200</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<Color red=\"{$red}\" green=\"{$green}\" blue=\"{$blue}\"/>\n"
"</xsl:template>\n"
"\n"
"<!-- ColorRGBA from @color=\"#rrggbbaa\" or @red, @green, @blue, @alpha -->\n"
"<xsl:template name=\"color-rgba\">\n"
"	<xsl:variable name=\"red\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@red\"><xsl:value-of select=\"@red\"/></xsl:when>\n"
"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,2,2)\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"green\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@green\"><xsl:value-of select=\"@green\"/></xsl:when>\n"
"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,4,2)\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"blue\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@blue\"><xsl:value-of select=\"@blue\"/></xsl:when>\n"
"			<xsl:when test=\"@color\">0x<xsl:value-of select=\"substring(@color,6)\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"alpha\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@alpha\"><xsl:value-of select=\"@alpha\"/></xsl:when>\n"
"			<xsl:when test=\"string-length(@color) = 9\">0x<xsl:value-of select=\"substring(@color,8)\"/></xsl:when>\n"
"			<xsl:otherwise>255</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<Color red=\"{$red}\" green=\"{$green}\" blue=\"{$blue}\" alpha=\"{$alpha}\"/>\n"
"</xsl:template>\n"
"\n"
"<!-- background color -->\n"
"<xsl:template match=\"background\">\n"
"	<SetBackgroundColor>\n"
"		<color>\n"
"			<xsl:call-template name=\"color\"/>\n"
"		</color>\n"
"	</SetBackgroundColor>\n"
"</xsl:template>\n"
"\n"
"<!-- library just passes thru, children decide wether to export by themselves -->\n"
"<xsl:template match=\"library\">\n"
"	<xsl:apply-templates/>\n"
"</xsl:template>\n"
"\n"
"<!-- linkage export -->\n"
"<xsl:template match=\"@id\" mode=\"export\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<Export count=\"1\">\n"
"		<symbols>\n"
"			<Symbol objectID=\"{$id}\">\n"
"				<xsl:attribute name=\"name\"><xsl:value-of select=\".\"/></xsl:attribute>\n"
"			</Symbol>\n"
"		</symbols>\n"
"	</Export>\n"
"</xsl:template>\n"
"<xsl:template match=\"@*\" mode=\"export\" priority=\"-1\"/>\n"
"\n"
"<!-- place -->\n"
"<xsl:template match=\"place\">\n"
"	<xsl:variable name=\"id\">\n"
"		<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"x\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@x\"><xsl:value-of select=\"@x * 20\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"y\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@y\"><xsl:value-of select=\"@y * 20\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"scale\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@scale\"><xsl:value-of select=\"@scale\"/></xsl:when>\n"
"			<xsl:otherwise>1</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"depth\"><xsl:value-of select=\"@depth\"/></xsl:variable>\n"
"	\n"
"	<!-- if we have a former place with the same depth, use morph=\"1\" replace=\"0\"\n"
"		 using morph=\"0\" and replace=\"1\" only works for the same objectID\n"
"		 that is already placed in layer (depth) -->\n"
"	<xsl:variable name=\"replace\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"preceding-sibling::place[@depth=$depth] or ../preceding-sibling::frame/place[@depth=$depth]\">1</xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:if test=\"$replace = '1'\">\n"
"		<RemoveObject2 depth=\"{@depth}\"/>\n"
"	</xsl:if>\n"
"	<PlaceObject2 replace=\"0\" morph=\"{$replace}\" depth=\"{$depth}\" objectID=\"{$id}\" name=\"{@name}\">\n"
"		<transform>\n"
"			<Transform transX=\"{$x}\" transY=\"{$y}\" scaleX=\"{$scale}\" scaleY=\"{$scale}\"/>\n"
"		</transform>\n"
"	</PlaceObject2>\n"
"</xsl:template>\n"
"\n"
"<!-- transform -->\n"
"<xsl:template match=\"transform\">\n"
"	<xsl:variable name=\"id\">\n"
"		<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"myid\">\n"
"		<xsl:value-of select=\"@id\"/>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"x\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@x\"><xsl:value-of select=\"@x * 20\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"y\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@y\"><xsl:value-of select=\"@y * 20\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"scale\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@scale\"><xsl:value-of select=\"@scale\"/></xsl:when>\n"
"			<xsl:otherwise>1</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"depth\">\n"
"		<xsl:value-of select=\"preceding-sibling::place[@id=$myid]/@depth\"/>\n"
"	</xsl:variable>\n"
"	\n"
"	<PlaceObject2 replace=\"1\" depth=\"{$depth}\" objectID=\"{$id}\">\n"
"		<transform>\n"
"			<Transform transX=\"{$x}\" transY=\"{$y}\" scaleX=\"{$scale}\" scaleY=\"{$scale}\"/>\n"
"		</transform>\n"
"	</PlaceObject2>\n"
"</xsl:template>\n"
"\n"
"<!-- texfield -->\n"
"<xsl:template match=\"textfield\">\n"
"	<xsl:variable name=\"id\">\n"
"		<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"x\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@x\"><xsl:value-of select=\"@x * 20\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"y\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@y\"><xsl:value-of select=\"@y * 20\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"width\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@width\"><xsl:value-of select=\"@width * 20\"/></xsl:when>\n"
"			<xsl:otherwise>100</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"height\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@height\"><xsl:value-of select=\"@height * 20\"/></xsl:when>\n"
"			<xsl:otherwise>100</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"size\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@size\"><xsl:value-of select=\"@size * 20\"/></xsl:when>\n"
"			<xsl:otherwise>240</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"\n"
"	<DefineEditText objectID=\"{$id}\" wordWrap=\"1\" multiLine=\"1\" password=\"0\" \n"
"		readOnly=\"0\" autoSize=\"0\" hasLayout=\"1\"\n"
"		notSelectable=\"0\" hasBorder=\"0\" isHTML=\"0\" useOutlines=\"1\" \n"
"		fontRef=\"{swft:map-id(@font)}\" fontHeight=\"{$size}\"\n"
"		align=\"0\" leftMargin=\"0\" rightMargin=\"0\" indent=\"0\" leading=\"40\" \n"
"		variableName=\"{@name}\" initialText=\"{@text}\">\n"
"		<size>\n"
"			<Rectangle left=\"{$x}\" right=\"{$x + $width}\" top=\"{$y}\" bottom=\"{$y + $height}\"/>\n"
"		</size>\n"
"		<color>\n"
"			<xsl:call-template name=\"color-rgba\"/>\n"
"		</color>\n"
"	</DefineEditText>\n"
"\n"
"</xsl:template>\n"
"\n"
"<!-- video object -->\n"
"<xsl:template match=\"video\">\n"
"	<xsl:variable name=\"id\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@id\">\n"
"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
"			</xsl:when>\n"
"			<xsl:otherwise>\n"
"				<xsl:value-of select=\"swft:next-id()\"/>\n"
"			</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"frames\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@frames\"><xsl:value-of select=\"@frames\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"width\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@width\"><xsl:value-of select=\"@width\"/></xsl:when>\n"
"			<xsl:otherwise>160</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"height\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@height\"><xsl:value-of select=\"@height\"/></xsl:when>\n"
"			<xsl:otherwise>120</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"deblocking\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@deblocking\"><xsl:value-of select=\"@deblocking\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"smoothing\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@smoothing\">1</xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"codec\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@codec\"><xsl:value-of select=\"@codec\"/></xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<DefineVideoStream objectID=\"{$id}\" frames=\"{$frames}\" width=\"{$width}\" height=\"{$height}\" deblocking=\"{$deblocking}\" smoothing=\"{$smoothing}\" codec=\"{$codec}\"/>\n"
"</xsl:template>\n"
"\n"
"<!-- frame -->\n"
"<xsl:template match=\"frame\">\n"
"	<xsl:apply-templates/>\n"
"	<xsl:if test=\"@name\">\n"
"		<FrameLabel label=\"{@name}\"/>\n"
"	</xsl:if>\n"
"	<ShowFrame/>\n"
"</xsl:template>\n"
"\n"
"<!-- clips -->\n"
"<xsl:template match=\"clip\" priority=\"-1\">\n"
"	<xsl:variable name=\"id\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@id\">\n"
"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
"			</xsl:when>\n"
"			<xsl:otherwise>\n"
"				<xsl:value-of select=\"swft:next-id()\"/>\n"
"			</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"			<xsl:apply-templates/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>	\n"
"	<xsl:if test=\"ancestor::library\">\n"
"		<xsl:apply-templates select=\"*|@*\" mode=\"export\">\n"
"			<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
"		</xsl:apply-templates>\n"
"	</xsl:if>\n"
"	<xsl:if test=\"@class\">\n"
"		<xsl:call-template name=\"register-class\">\n"
"			<xsl:with-param name=\"class\" select=\"@class\"/>\n"
"			<xsl:with-param name=\"linkage-id\" select=\"@id\"/>\n"
"		</xsl:call-template>\n"
"	</xsl:if>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"clip[@import]\">\n"
"	<xsl:variable name=\"id\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@id\">\n"
"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
"			</xsl:when>\n"
"			<xsl:otherwise>\n"
"				<xsl:value-of select=\"swft:next-id()\"/>\n"
"			</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"file\">\n"
"		<xsl:value-of select=\"@import\"/>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"ext\">\n"
"		<xsl:value-of select=\"translate(substring(@import,string-length(@import)-2),'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')\"/>\n"
"	</xsl:variable>\n"
"	<xsl:choose>\n"
"		<xsl:when test=\"$ext = 'jpg' or $ext = 'peg'\">\n"
"			<xsl:apply-templates select=\"swft:import-jpeg($file)\" mode=\"makeswf\">\n"
"				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
"			</xsl:apply-templates>\n"
"		</xsl:when>\n"
"		<xsl:when test=\"$ext = 'png'\">\n"
"			<xsl:apply-templates select=\"swft:import-png($file)\" mode=\"makeswf\">\n"
"				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
"			</xsl:apply-templates>\n"
"		</xsl:when>\n"
"		<xsl:when test=\"$ext = 'swf'\">\n"
"			<xsl:apply-templates select=\"swft:document($file)\" mode=\"makeswf\">\n"
"				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
"			</xsl:apply-templates>\n"
"		</xsl:when>\n"
"		<xsl:when test=\"$ext = 'ttf'\">\n"
"			<xsl:apply-templates select=\"swft:import-ttf($file,@glyphs)\" mode=\"makeswf\">\n"
"				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
"			</xsl:apply-templates>\n"
"		</xsl:when>\n"
"		<xsl:when test=\"$ext = 'svg'\">\n"
"			<xsl:apply-templates select=\"document($file)\" mode=\"makesvg\">\n"
"				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
"			</xsl:apply-templates>\n"
"		</xsl:when>\n"
"	</xsl:choose>\n"
"	<xsl:if test=\"ancestor::library\">\n"
"		<xsl:apply-templates select=\"*|@*\" mode=\"export\">\n"
"			<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
"		</xsl:apply-templates>\n"
"	</xsl:if>\n"
"	<xsl:if test=\"@class\">\n"
"		<xsl:call-template name=\"register-class\">\n"
"			<xsl:with-param name=\"class\" select=\"@class\"/>\n"
"			<xsl:with-param name=\"linkage-id\" select=\"@id\"/>\n"
"		</xsl:call-template>\n"
"	</xsl:if>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"font[@import]\">\n"
"	<xsl:variable name=\"id\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@id\">\n"
"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
"			</xsl:when>\n"
"			<xsl:otherwise>\n"
"				<xsl:value-of select=\"swft:next-id()\"/>\n"
"			</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"file\">\n"
"		<xsl:value-of select=\"@import\"/>\n"
"	</xsl:variable>\n"
"	\n"
"	<xsl:apply-templates select=\"swft:import-ttf($file,@glyphs)\" mode=\"makeswf\">\n"
"		<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
"	</xsl:apply-templates>\n"
"</xsl:template>\n"
"\n"
"<!-- JPEG import -->\n"
"<xsl:template match=\"jpeg\" mode=\"makeswf\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<xsl:variable name=\"bitmapID\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
"	<xsl:variable name=\"shapeID\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
"	<DefineBitsJPEG2 objectID=\"{$bitmapID}\">\n"
"		<data>\n"
"			<xsl:copy-of select=\"data\"/>\n"
"		</data>\n"
"	</DefineBitsJPEG2>\n"
"	<DefineShape objectID=\"{$shapeID}\">\n"
"		<bounds>\n"
"			<Rectangle left=\"0\" right=\"{@width}\" top=\"0\" bottom=\"{@height}\"/>\n"
"		</bounds>\n"
"		<styles>\n"
"			<StyleList>\n"
"				<fillStyles>\n"
"					<ClippedBitmap objectID=\"{$bitmapID}\">\n"
"						<matrix>\n"
"							<Transform transX=\"0\" transY=\"0\"/>\n"
"						</matrix>\n"
"					</ClippedBitmap>\n"
"				</fillStyles>\n"
"				<lineStyles/>\n"
"			</StyleList>\n"
"		</styles>\n"
"		<shapes>\n"
"			<Shape>\n"
"				<edges>\n"
"					<ShapeSetup x=\"{@width}\" y=\"{@height}\" fillStyle1=\"1\"/>\n"
"					<LineTo x=\"-{@width}\" y=\"0\"/>\n"
"					<LineTo x=\"0\" y=\"-{@height}\"/>\n"
"					<LineTo x=\"{@width}\" y=\"0\"/>\n"
"					<LineTo x=\"0\" y=\"{@height}\"/>\n"
"					<ShapeSetup/>\n"
"				</edges>\n"
"			</Shape>\n"
"		</shapes>\n"
"	</DefineShape>\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"			<PlaceObject2 replace=\"0\" depth=\"1\" objectID=\"{$shapeID}\">\n"
"				<transform>\n"
"					<Transform transX=\"0\" transY=\"0\" scaleX=\"20\" scaleY=\"20\"/>\n"
"				</transform>\n"
"			</PlaceObject2>\n"
"			<ShowFrame/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"</xsl:template>\n"
"\n"
"<!-- PNG import -->\n"
"<xsl:template match=\"png\" mode=\"makeswf\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<xsl:variable name=\"bitmapID\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
"	<xsl:variable name=\"shapeID\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
"	<DefineBitsLossless2 format=\"{@format}\" width=\"{@width}\" height=\"{@height}\" objectID=\"{$bitmapID}\">\n"
"		<data>\n"
"			<xsl:copy-of select=\"data\"/>\n"
"		</data>\n"
"	</DefineBitsLossless2>\n"
"	<DefineShape objectID=\"{$shapeID}\">\n"
"		<bounds>\n"
"			<Rectangle left=\"0\" right=\"{@width}\" top=\"0\" bottom=\"{@height}\"/>\n"
"		</bounds>\n"
"		<styles>\n"
"			<StyleList>\n"
"				<fillStyles>\n"
"					<ClippedBitmap objectID=\"{$bitmapID}\">\n"
"						<matrix>\n"
"							<Transform transX=\"0\" transY=\"0\"/>\n"
"						</matrix>\n"
"					</ClippedBitmap>\n"
"				</fillStyles>\n"
"				<lineStyles/>\n"
"			</StyleList>\n"
"		</styles>\n"
"		<shapes>\n"
"			<Shape>\n"
"				<edges>\n"
"					<ShapeSetup x=\"{@width}\" y=\"{@height}\" fillStyle1=\"1\"/>\n"
"					<LineTo x=\"-{@width}\" y=\"0\"/>\n"
"					<LineTo x=\"0\" y=\"-{@height}\"/>\n"
"					<LineTo x=\"{@width}\" y=\"0\"/>\n"
"					<LineTo x=\"0\" y=\"{@height}\"/>\n"
"					<ShapeSetup/>\n"
"				</edges>\n"
"			</Shape>\n"
"		</shapes>\n"
"	</DefineShape>\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"			<PlaceObject2 replace=\"0\" depth=\"1\" objectID=\"{$shapeID}\">\n"
"				<transform>\n"
"					<Transform transX=\"0\" transY=\"0\" scaleX=\"20\" scaleY=\"20\"/>\n"
"				</transform>\n"
"			</PlaceObject2>\n"
"			<ShowFrame/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"</xsl:template>\n"
"\n"
"\n"
"<!-- SWF import -->\n"
"<xsl:template match=\"swf\" mode=\"makeswf\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<swft:push-map/>\n"
"\n"
"	<xsl:apply-templates select=\"Header/tags/*\" mode=\"sprite-global\"/>\n"
"	\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"{count(Header/tags/ShowFrame)}\">\n"
"		<tags>\n"
"			<xsl:apply-templates select=\"Header/tags/*\" mode=\"sprite-local\"/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"	\n"
"	<swft:pop-map/>\n"
"</xsl:template>\n"
"\n"
"<!-- SVG import -->\n"
"<xsl:template match=\"svg:svg\" mode=\"makesvg\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"			<xsl:apply-templates mode=\"svg\"/>\n"
"			<ShowFrame/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"svg:g|svg:path|svg:rect\" mode=\"svg\">\n"
"	<xsl:variable name=\"id\"><xsl:value-of select=\"swft:map-id(@id)\"/></xsl:variable> \n"
"	<xsl:variable name=\"xofs\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@inkscape:px\">\n"
"				<xsl:value-of select=\"@inkscape:px\"/>\n"
"			</xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable> \n"
"	<xsl:variable name=\"yofs\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@inkscape:py\">\n"
"				<xsl:value-of select=\"@inkscape:py\"/>\n"
"			</xsl:when>\n"
"			<xsl:otherwise>0</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable> \n"
"	<xsl:variable name=\"name\" select=\"@id\"/>\n"
"	<xsl:variable name=\"class\" select=\"@class\"/>\n"
"\n"
"	<xsl:apply-templates select=\".\" mode=\"svg-inner\">\n"
"		<xsl:with-param name=\"id\" select=\"$id\"/>\n"
"		<xsl:with-param name=\"xofs\" select=\"$xofs\"/>\n"
"		<xsl:with-param name=\"yofs\" select=\"$yofs\"/>\n"
"	</xsl:apply-templates>\n"
"\n"
"	<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$id}\" name=\"{$name}\">\n"
"		<transform>\n"
"			<Transform transX=\"{$xofs*20}\" transY=\"{$yofs*20}\"/>\n"
"		</transform>\n"
"	</PlaceObject2>\n"
"\n"
"	<Export>\n"
"		<symbols>\n"
"		  <Symbol objectID=\"{$id}\" name=\"{$name}\"/>\n"
"		</symbols>\n"
"	</Export>\n"
"	\n"
"		<!-- debugging: spin everything\n"
"		<xsl:call-template name=\"register-class\">\n"
"			<xsl:with-param name=\"class\">org.iterative.Spinner</xsl:with-param>\n"
"			<xsl:with-param name=\"linkage-id\" select=\"$name\"/>\n"
"		</xsl:call-template>\n"
"	-->\n"
"	<xsl:if test=\"string-length($class) > 0\">\n"
"		<xsl:call-template name=\"register-class\">\n"
"			<xsl:with-param name=\"class\" select=\"$class\"/>\n"
"			<xsl:with-param name=\"linkage-id\" select=\"$name\"/>\n"
"		</xsl:call-template>\n"
"	</xsl:if>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"svg:g\" mode=\"svg-inner\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<xsl:param name=\"xofs\"/>\n"
"	<xsl:param name=\"yofs\"/>\n"
"	<xsl:variable name=\"subid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
"\n"
"	<DefineSprite objectID=\"{$subid}\" frames=\"1\">\n"
"		<tags>\n"
"			<xsl:apply-templates mode=\"svg\"/>\n"
"			<ShowFrame/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$subid}\">\n"
"				<transform>\n"
"					<xsl:choose>\n"
"						<xsl:when test=\"@transform\">\n"
"							<xsl:copy-of select=\"swft:transform(@transform,-$xofs,-$yofs)\"/>\n"
"						</xsl:when>\n"
"						<xsl:otherwise>\n"
"							<Transform transX=\"{$xofs*-20}\" transY=\"{$yofs*-20}\"/>\n"
"						</xsl:otherwise>\n"
"					</xsl:choose>\n"
"				</transform>\n"
"			</PlaceObject2>\n"
"			<ShowFrame/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"svg:path\" mode=\"svg-inner\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<xsl:param name=\"xofs\"/>\n"
"	<xsl:param name=\"yofs\"/>\n"
"	<xsl:variable name=\"shapeid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
"\n"
"	<DefineShape3 objectID=\"{$shapeid}\">\n"
"		<bounds>\n"
"			<!-- bounds needs to respect offset? -->\n"
"				<xsl:copy-of select=\"swft:bounds(@d,-$xofs,-$yofs)\"/>\n"
"		</bounds>\n"
"		<styles>\n"
"			<StyleList>\n"
"				<xsl:copy-of select=\"swft:css(@style)/tmp/*\"/>\n"
"			</StyleList>\n"
"		</styles>\n"
"		<shapes>\n"
"			<Shape>\n"
"				<xsl:apply-templates mode=\"shape\" select=\"swft:path(@d,-$xofs,-$yofs)/tmp/Shape/*\"/>\n"
"			</Shape>\n"
"		</shapes>\n"
"	</DefineShape3>\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$shapeid}\">\n"
"				<transform>\n"
"			<xsl:choose>\n"
"				<xsl:when test=\"@transform\">\n"
"					<xsl:copy-of select=\"swft:transform(@transform)\"/>\n"
"				</xsl:when>\n"
"				<xsl:otherwise>\n"
"					<Transform transX=\"0\" transY=\"0\"/>\n"
"				</xsl:otherwise>\n"
"			</xsl:choose>\n"
"				</transform>\n"
"			</PlaceObject2>\n"
"			<ShowFrame/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"svg:rect\" mode=\"svg-inner\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<xsl:param name=\"xofs\"/>\n"
"	<xsl:param name=\"yofs\"/>\n"
"	<xsl:variable name=\"shapeid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
"\n"
"	<DefineShape3 objectID=\"{$shapeid}\">\n"
"		<bounds>\n"
"			<Rectangle left=\"0\" right=\"{@width*20}\" top=\"0\" bottom=\"{@height*20}\"/>\n"
"		</bounds>\n"
"		<styles>\n"
"			<StyleList>\n"
"				<xsl:copy-of select=\"swft:css(@style)/tmp/*\"/>\n"
"			</StyleList>\n"
"		</styles>\n"
"		<shapes>\n"
"			<Shape>\n"
"				<edges>\n"
"					<ShapeSetup x=\"{(@width)*20}\" y=\"{(@height)*20}\" fillStyle0=\"1\" lineStyle=\"1\"/>\n"
"					<LineTo x=\"-{(@width)*20}\" y=\"0\"/>\n"
"					<LineTo x=\"0\" y=\"-{(@height)*20}\"/>\n"
"					<LineTo x=\"{(@width)*20}\" y=\"0\"/>\n"
"					<LineTo x=\"0\" y=\"{(@height)*20}\"/>\n"
"					<ShapeSetup/>\n"
"				</edges>\n"
"			</Shape>\n"
"		</shapes>\n"
"	</DefineShape3>\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$shapeid}\">\n"
"				<transform>\n"
"					<Transform transX=\"{(@x - $xofs)*20}\" transY=\"{(@y - $yofs)*20}\"/>\n"
"				</transform>\n"
"			</PlaceObject2>\n"
"			<ShowFrame/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"svg:flowRoot\" mode=\"svg-inner\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<xsl:param name=\"xofs\"/>\n"
"	<xsl:param name=\"yofs\"/>\n"
"	<xsl:variable name=\"subid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable> \n"
"\n"
"	<DefineEditText objectID=\"{$subid}\" wordWrap=\"1\" multiLine=\"1\" password=\"0\" \n"
"		readOnly=\"1\" autoSize=\"0\" hasLayout=\"1\"\n"
"		notSelectable=\"1\" hasBorder=\"0\" isHTML=\"0\" useOutlines=\"1\" \n"
"		fontRef=\"{swft:map-id(vera)}\" fontHeight=\"12\"\n"
"		align=\"0\" leftMargin=\"0\" rightMargin=\"0\" indent=\"0\" leading=\"40\" \n"
"		variableName=\"{@id}\">\n"
"		<xsl:attribute name=\"initialText\">\n"
"			foo?\n"
"		</xsl:attribute>\n"
"		<size>\n"
"			<Rectangle left=\"{svg:flowRegion/@x}\" \n"
"						right=\"{svg:flowRegion/@x + svg:flowRegion/@width}\" \n"
"						top=\"{svg:flowRegion/@y}\" \n"
"						bottom=\"{$svg:flowRegion/@y + $svg:flowRegion/@height}\"/>\n"
"		</size>\n"
"		<color>\n"
"			<Color red=\"255\" green=\"255\" blue=\"255\"/>\n"
"		</color>\n"
"	</DefineEditText>\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$subid}\">\n"
"				<transform>\n"
"					<xsl:choose>\n"
"						<xsl:when test=\"@transform\">\n"
"							<xsl:copy-of select=\"swft:transform(@transform,-$xofs,-$yofs)\"/>\n"
"						</xsl:when>\n"
"						<xsl:otherwise>\n"
"							<Transform transX=\"{$xofs*-20}\" transY=\"{$yofs*-20}\"/>\n"
"						</xsl:otherwise>\n"
"					</xsl:choose>\n"
"				</transform>\n"
"			</PlaceObject2>\n"
"			<ShowFrame/>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"*|@*|text()\" mode=\"svg\" priority=\"-1\"/>\n"
"\n"
"\n"
"<xsl:template match=\"ShapeSetup\" mode=\"shape\">\n"
"	<ShapeSetup fillStyle0=\"1\" fillStyle1=\"2\" lineStyle=\"1\">\n"
"		<xsl:apply-templates select=\"*|@*\" mode=\"shape\"/>\n"
"	</ShapeSetup>\n"
"</xsl:template>\n"
"<xsl:template match=\"*|@*|text()\" mode=\"shape\" priority=\"-1\">\n"
"	<xsl:copy-of select=\".\"/>\n"
"</xsl:template>\n"
"\n"
"\n"
"<!-- shared library import -->\n"
"<xsl:template match=\"import\">\n"
"	<Import url=\"{@url}\">\n"
"		<symbols>\n"
"			<xsl:if test=\"@symbol\">\n"
"				<Symbol objectID=\"{swft:map-id(@symbol)}\" name=\"{@symbol}\"/>\n"
"			</xsl:if>	\n"
"			<xsl:if test=\"@file\">\n"
"				<xsl:apply-templates select=\"swft:document(@file)/swf/Header/tags/Export/symbols/*\" mode=\"import\"/>\n"
"			</xsl:if>\n"
"		</symbols>\n"
"	</Import>\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"Symbol\" mode=\"import\">\n"
"	<Symbol objectID=\"{swft:map-id(@name)}\" name=\"{@name}\"/>\n"
"</xsl:template>\n"
"\n"
"<!-- global id remapping -->\n"
"<xsl:template match=\"@objectID|@fontRef|@sprite\" mode=\"idmap\">\n"
"	<xsl:attribute name=\"{name()}\"><xsl:value-of select=\"swft:map-id(.)\"/></xsl:attribute>\n"
"</xsl:template>\n"
"<xsl:template match=\"*|@*|text()\" mode=\"idmap\" priority=\"-1\">\n"
"	<xsl:copy select=\".\">\n"
"		<xsl:apply-templates select=\"*|@*|text()\" mode=\"idmap\"/>\n"
"	</xsl:copy>\n"
"</xsl:template>\n"
"\n"
"<!-- for tags that are \"globalized\" -->\n"
"<xsl:template match=\"SetBackgroundColor\" mode=\"sprite-global\"/>\n"
"<xsl:template match=\"DoAction|End|FrameLabel|PlaceObject|PlaceObject2|RemoveObject|RemoveObject2|ShowFrame|SoundStreamBlock|SoundStreamHead|StartSound\" mode=\"sprite-global\"/>\n"
"<xsl:template match=\"*|@*|text()\" mode=\"sprite-global\" priority=\"-1\">\n"
"	<xsl:apply-templates select=\".\" mode=\"idmap\"/>\n"
"</xsl:template>\n"
"\n"
"<!-- for tags that move into the DefineSprite -->\n"
"<xsl:template match=\"DoAction|End|FrameLabel|PlaceObject|PlaceObject2|RemoveObject|RemoveObject2|ShowFrame|SoundStreamBlock|SoundStreamHead|StartSound\" mode=\"sprite-local\">\n"
"	<xsl:apply-templates select=\".\" mode=\"idmap\"/>\n"
"</xsl:template>\n"
"<xsl:template match=\"*|@*|text()\" mode=\"sprite-local\" priority=\"-1\"/>\n"
"\n"
"\n"
"<!-- TTF import -->\n"
"<xsl:template match=\"ttf\" mode=\"makeswf\">\n"
"	<xsl:param name=\"id\"/>\n"
"	<DefineFont2 objectID=\"{$id}\">\n"
"		<xsl:apply-templates select=\"DefineFont2/*|DefineFont2/@*[name() != 'objectID']\"/>\n"
"	</DefineFont2>\n"
"</xsl:template>\n"
"\n"
"<!-- call -->\n"
"<xsl:template match=\"call\">\n"
"	<xsl:variable name=\"object\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@object\"><xsl:value-of select=\"@object\"/></xsl:when>\n"
"			<xsl:otherwise>Main</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"method\">\n"
"		<xsl:choose>\n"
"			<xsl:when test=\"@method\"><xsl:value-of select=\"@method\"/></xsl:when>\n"
"			<xsl:otherwise>main</xsl:otherwise>\n"
"		</xsl:choose>\n"
"	</xsl:variable>\n"
"	<xsl:variable name=\"spriteid\">\n"
"		<xsl:value-of select=\"swft:next-id()\"/>\n"
"	</xsl:variable>\n"
"	<DefineSprite objectID=\"{$spriteid}\" frames=\"1\">\n"
"		<tags>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"	<Export>\n"
"		<symbols>\n"
"			<Symbol objectID=\"{$spriteid}\" name=\"__Packages.swfmill.call.{$object}.{$method}\"/>\n"
"		</symbols>\n"
"	</Export>\n"
"	<DoInitAction sprite=\"{$spriteid}\">\n"
"		<actions>\n"
"			<PushData>\n"
"				<items>\n"
"					<StackString value=\"{@object}\"/>\n"
"				</items>\n"
"			</PushData>\n"
"			<GetVariable/>\n"
"			<PushData>\n"
"				<items>\n"
"					<StackString value=\"{@method}\"/>\n"
"				</items>\n"
"			</PushData>\n"
"			<CallMethod/>\n"
"			<Pop/>\n"
"			<EndAction/>\n"
"		</actions>\n"
"	</DoInitAction>\n"
"</xsl:template>\n"
"\n"
"<!-- works only if the id is exported! -->\n"
"<xsl:template name=\"register-class\">\n"
"	<xsl:param name=\"class\"/>\n"
"	<xsl:param name=\"linkage-id\"/>\n"
"	<xsl:variable name=\"packages\" select=\"str:tokenize($class,'.')\"/>\n"
"	<xsl:variable name=\"strofs\">3</xsl:variable>\n"
"	<xsl:variable name=\"id\" select=\"swft:next-id()\"/>\n"
"\n"
"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
"		<tags>\n"
"		  <End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"	<Export>\n"
"		<symbols>\n"
"		  <Symbol objectID=\"{$id}\" name=\"__Packages.swfmill.registerClass.{$linkage-id}\"/>\n"
"		</symbols>\n"
"	</Export>\n"
"	<DoInitAction sprite=\"{$id}\">\n"
"		<actions>\n"
"			<Dictionary>\n"
"				<strings>\n"
"					<String value=\"Object\"/>\n"
"					<String value=\"registerClass\"/>\n"
"					<String value=\"{$linkage-id}\"/>\n"
"					<xsl:for-each select=\"$packages\">\n"
"						<String value=\"{.}\"/>\n"
"					</xsl:for-each>\n"
"				</strings>\n"
"			</Dictionary>\n"
"			\n"
"			<!-- package root -->\n"
"			<PushData>\n"
"				<items>\n"
"				  <StackDictionaryLookup index=\"{$strofs}\"/> \n"
"				</items>\n"
"			</PushData>\n"
"			<GetVariable/>\n"
"			\n"
"			<!-- packages -->\n"
"			<xsl:for-each select=\"$packages[position()>1]\">\n"
"				<PushData>\n"
"					<items>\n"
"					  <StackDictionaryLookup index=\"{$strofs + position()}\"/>\n"
"					</items>\n"
"				</PushData>\n"
"				<GetMember/>\n"
"			</xsl:for-each>\n"
"			\n"
"			<!-- linkage id, 2 (arguments), Object-->\n"
"			<PushData>\n"
"				<items>\n"
"				  <StackDictionaryLookup index=\"2\"/>\n"
"				  <StackInteger value=\"2\"/>\n"
"				  <StackDictionaryLookup index=\"0\"/>\n"
"				</items>\n"
"			</PushData>\n"
"			<GetVariable/>\n"
"			<!-- registerClass -->\n"
"			<PushData>\n"
"				<items>\n"
"				  <StackDictionaryLookup index=\"1\"/>\n"
"				</items>\n"
"			</PushData>\n"
"			<CallMethod/>\n"
"			<Pop/>\n"
"			<EndAction/>\n"
"		</actions>\n"
"	</DoInitAction>\n"
"	\n"
"</xsl:template>\n"
"\n"
"<xsl:template match=\"set\">\n"
"	<xsl:variable name=\"spriteid\">\n"
"		<xsl:value-of select=\"swft:next-id()\"/>\n"
"	</xsl:variable>\n"
"	<DefineSprite objectID=\"{$spriteid}\" frames=\"1\">\n"
"		<tags>\n"
"			<End/>\n"
"		</tags>\n"
"	</DefineSprite>\n"
"	<Export>\n"
"		<symbols>\n"
"			<Symbol objectID=\"{$spriteid}\" name=\"__Packages.swfmill.set.{@name}.{@member}\"/>\n"
"		</symbols>\n"
"	</Export>\n"
"	<DoInitAction sprite=\"{$spriteid}\">\n"
"		<actions>\n"
"			<Dictionary>\n"
"				<strings>\n"
"					<String value=\"_root\"/>\n"
"					<String value=\"{@name}\"/>\n"
"					<String value=\"{@member}\"/>\n"
"					<String value=\"{@value}\"/>\n"
"				</strings>\n"
"			</Dictionary>\n"
"			<PushData>\n"
"				<items>\n"
"					<StackDictionaryLookup index=\"0\"/>\n"
"				</items>\n"
"			</PushData>\n"
"			<GetVariable/>\n"
"			<PushData>\n"
"				<items>\n"
"					<StackDictionaryLookup index=\"1\"/>\n"
"				</items>\n"
"			</PushData>\n"
"			<GetMember/>\n"
"			<PushData>\n"
"				<items>\n"
"					<StackDictionaryLookup index=\"2\"/>\n"
"					<StackDictionaryLookup index=\"3\"/>\n"
"				</items>\n"
"			</PushData>\n"
"			<SetMember/>\n"
"			<EndAction/>\n"
"		</actions>\n"
"	</DoInitAction>\n"
"</xsl:template>\n"
"\n"
"<!-- stop -->\n"
"<xsl:template match=\"stop\">\n"
"	<DoAction>\n"
"		<actions>\n"
"			<Stop/>\n"
"			<EndAction/>\n"
"		</actions>\n"
"	</DoAction>\n"
"</xsl:template>\n"
"\n"
"\n"
"<!-- HTML wrapper -->\n"
"<xsl:template match=\"html-wrapper\">\n"
"	<xsl:document href=\"{@name}\">\n"
"<html>\n"
"	<body>\n"
"	<object classid=\"clsid:d27cdb6e-ae6d-11cf-96b8-444553540000\" \n"
"			codebase=\"http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0\" \n"
"			width=\"{/movie/@width}\" height=\"{/movie/@width}\" id=\"video\" align=\"middle\">\n"
"		<param name=\"allowScriptAccess\" value=\"sameDomain\" />\n"
"		<param name=\"movie\" value=\"{@swf}\" />\n"
"		<param name=\"quality\" value=\"high\" />\n"
"		<embed src=\"{@swf}\" quality=\"high\" \n"
"			width=\"{/movie/@width}\" height=\"{/movie/@height}\" name=\"video\" align=\"middle\" allowScriptAccess=\"sameDomain\" \n"
"			type=\"application/x-shockwave-flash\" pluginspage=\"http://www.macromedia.com/go/getflashplayer\" />\n"
"	</object>\n"
"	</body>\n"
"</html>\n"
"	</xsl:document>\n"
"</xsl:template>\n"
"\n"
"<!-- copy anything else -->\n"
"<xsl:template match=\"*|@*|text()\" priority=\"-1\">\n"
"	<xsl:copy select=\".\">\n"
"		<xsl:apply-templates select=\"*|@*|text()\"/>\n"
"	</xsl:copy>\n"
"</xsl:template>\n"
"\n"
"</xsl:stylesheet>\n"
;
